PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Enums.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Enumerations | Functions
Enums.hpp File Reference

Go to the source code of this file.

## Enumerations
enum | SignalType { USER = 0x0 , SIGNAL = 0x1 , POWER = 0x2 , GROUND = 0x4 , SIGNAL_POWER = 0x3 , SIGNAL_GROUND = 0x5 , POWER_GROUND = 0x6 , ANY = 0x7 }

## Functions
SignalType | signalType (const std::string_view)
std::string | to_string (SignalType)

## Enumeration Type Documentation

## ◆ SignalType

enum SignalType

Enumerator
USER |
SIGNAL |
POWER |
GROUND |
SIGNAL_POWER |
SIGNAL_GROUND |
POWER_GROUND |
ANY |

## Function Documentation

## ◆ signalType()

SignalType signalType | ( | const std::string_view |  | ) |

## ◆ to_string()

std::string to_string | ( | SignalType |  | ) |